pub struct CreateProofResponse {
pub success: bool,
pub proof: String,
pub error: String,
}Fields
success: boolproof: Stringerror: StringTrait Implementations
Sourceimpl Clone for CreateProofResponse
impl Clone for CreateProofResponse
Sourcefn clone(&self) -> CreateProofResponse
fn clone(&self) -> CreateProofResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateProofResponse
impl Debug for CreateProofResponse
Sourceimpl Default for CreateProofResponse
impl Default for CreateProofResponse
Sourceimpl<'de> Deserialize<'de> for CreateProofResponse
impl<'de> Deserialize<'de> for CreateProofResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CreateProofResponse
impl PartialEq for CreateProofResponse
Sourceimpl RosMessageType for CreateProofResponse
impl RosMessageType for CreateProofResponse
Sourceconst ROS_TYPE_NAME: &'static str = "common/CreateProofResponse"
const ROS_TYPE_NAME: &'static str = "common/CreateProofResponse"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "785e1c962648f130f873749ea2efe97b"
const MD5SUM: &'static str = "785e1c962648f130f873749ea2efe97b"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Response part\n\n# Success flag to indicate if the operation was successful\nbool success\n\n# proof of the data\nstring proof\n\n# message to indicate the reason for failure, empty if sucess is true\nstring error"
const DEFINITION: &'static str = "# Response part\n\n# Success flag to indicate if the operation was successful\nbool success\n\n# proof of the data\nstring proof\n\n# message to indicate the reason for failure, empty if sucess is true\nstring error"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for CreateProofResponse
impl Serialize for CreateProofResponse
impl StructuralPartialEq for CreateProofResponse