pub struct ETHTransferResponse {
pub success: bool,
pub tx_hash: String,
pub error: String,
}Fields
success: booltx_hash: Stringerror: StringTrait Implementations
Sourceimpl Clone for ETHTransferResponse
impl Clone for ETHTransferResponse
Sourcefn clone(&self) -> ETHTransferResponse
fn clone(&self) -> ETHTransferResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ETHTransferResponse
impl Debug for ETHTransferResponse
Sourceimpl Default for ETHTransferResponse
impl Default for ETHTransferResponse
Sourceimpl<'de> Deserialize<'de> for ETHTransferResponse
impl<'de> Deserialize<'de> for ETHTransferResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ETHTransferResponse
impl PartialEq for ETHTransferResponse
Sourceimpl RosMessageType for ETHTransferResponse
impl RosMessageType for ETHTransferResponse
Sourceconst ROS_TYPE_NAME: &'static str = "common/ETHTransferResponse"
const ROS_TYPE_NAME: &'static str = "common/ETHTransferResponse"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "f592de0a75d7b2f941be2acfa8427aa3"
const MD5SUM: &'static str = "f592de0a75d7b2f941be2acfa8427aa3"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# whether the tx was received or not (not if it was successful)\nbool success\n\n# the hash of the transaction\nstring tx_hash\n\n# the error of the transaction\nstring error"
const DEFINITION: &'static str = "# whether the tx was received or not (not if it was successful)\nbool success\n\n# the hash of the transaction\nstring tx_hash\n\n# the error of the transaction\nstring error"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for ETHTransferResponse
impl Serialize for ETHTransferResponse
impl StructuralPartialEq for ETHTransferResponse