pub struct HelloWorldResponse {
pub success: bool,
pub message: String,
}Fields
success: boolmessage: StringTrait Implementations
Sourceimpl Clone for HelloWorldResponse
impl Clone for HelloWorldResponse
Sourcefn clone(&self) -> HelloWorldResponse
fn clone(&self) -> HelloWorldResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HelloWorldResponse
impl Debug for HelloWorldResponse
Sourceimpl Default for HelloWorldResponse
impl Default for HelloWorldResponse
Sourceimpl<'de> Deserialize<'de> for HelloWorldResponse
impl<'de> Deserialize<'de> for HelloWorldResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for HelloWorldResponse
impl PartialEq for HelloWorldResponse
Sourceimpl RosMessageType for HelloWorldResponse
impl RosMessageType for HelloWorldResponse
Sourceconst ROS_TYPE_NAME: &'static str = "common/HelloWorldResponse"
const ROS_TYPE_NAME: &'static str = "common/HelloWorldResponse"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "937c9679a518e3a18d831e57125ea522"
const MD5SUM: &'static str = "937c9679a518e3a18d831e57125ea522"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Response\nbool success\nstring message"
const DEFINITION: &'static str = "# Response\nbool success\nstring message"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for HelloWorldResponse
impl Serialize for HelloWorldResponse
impl StructuralPartialEq for HelloWorldResponse