pub struct PublishCastResponse {
pub success: bool,
pub error: String,
}Fields
success: boolerror: StringTrait Implementations
Sourceimpl Clone for PublishCastResponse
impl Clone for PublishCastResponse
Sourcefn clone(&self) -> PublishCastResponse
fn clone(&self) -> PublishCastResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PublishCastResponse
impl Debug for PublishCastResponse
Sourceimpl Default for PublishCastResponse
impl Default for PublishCastResponse
Sourceimpl<'de> Deserialize<'de> for PublishCastResponse
impl<'de> Deserialize<'de> for PublishCastResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PublishCastResponse
impl PartialEq for PublishCastResponse
Sourceimpl RosMessageType for PublishCastResponse
impl RosMessageType for PublishCastResponse
Sourceconst ROS_TYPE_NAME: &'static str = "common/PublishCastResponse"
const ROS_TYPE_NAME: &'static str = "common/PublishCastResponse"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "45872d25d65c97743cc71afc6d4e884d"
const MD5SUM: &'static str = "45872d25d65c97743cc71afc6d4e884d"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Response\n\n# Success flag\nbool success\n\n# Error message\nstring error"
const DEFINITION: &'static str = "# Response\n\n# Success flag\nbool success\n\n# Error message\nstring error"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for PublishCastResponse
impl Serialize for PublishCastResponse
impl StructuralPartialEq for PublishCastResponse