pub struct SnapshotTopicDataRequest {
pub topic: String,
pub duration: f64,
pub target_path: String,
pub max_record_count: u16,
}Fields
topic: Stringduration: f64target_path: Stringmax_record_count: u16Trait Implementations
Sourceimpl Clone for SnapshotTopicDataRequest
impl Clone for SnapshotTopicDataRequest
Sourcefn clone(&self) -> SnapshotTopicDataRequest
fn clone(&self) -> SnapshotTopicDataRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotTopicDataRequest
impl Debug for SnapshotTopicDataRequest
Sourceimpl Default for SnapshotTopicDataRequest
impl Default for SnapshotTopicDataRequest
Sourceimpl<'de> Deserialize<'de> for SnapshotTopicDataRequest
impl<'de> Deserialize<'de> for SnapshotTopicDataRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SnapshotTopicDataRequest
impl PartialEq for SnapshotTopicDataRequest
Sourceimpl RosMessageType for SnapshotTopicDataRequest
impl RosMessageType for SnapshotTopicDataRequest
Sourceconst ROS_TYPE_NAME: &'static str = "common/SnapshotTopicDataRequest"
const ROS_TYPE_NAME: &'static str = "common/SnapshotTopicDataRequest"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "f2602be7b44da1b87303cb986e033a23"
const MD5SUM: &'static str = "f2602be7b44da1b87303cb986e033a23"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# SnapshotTopicData.srv\n\n# topic name to record e.g. \"/camera/rgb/image_raw\"\nstring topic\n\n# Duration for which it should be recorded (in seconds)\nfloat64 duration\n\n# Target path to save the recorded topic data\n# An empty string will default to a predefined path\nstring target_path\n\n# Number of times the service should record\n# 0 if it should go on forever\n# default: 0 (forever)\nuint16 max_record_count"
const DEFINITION: &'static str = "# SnapshotTopicData.srv\n\n# topic name to record e.g. \"/camera/rgb/image_raw\"\nstring topic\n\n# Duration for which it should be recorded (in seconds)\nfloat64 duration\n\n# Target path to save the recorded topic data\n# An empty string will default to a predefined path\nstring target_path\n\n# Number of times the service should record\n# 0 if it should go on forever\n# default: 0 (forever)\nuint16 max_record_count"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for SnapshotTopicDataRequest
impl Serialize for SnapshotTopicDataRequest
impl StructuralPartialEq for SnapshotTopicDataRequest