pub struct AccelWithCovariance {
pub accel: Accel,
pub covariance: Vec<f64>,
}Fields
accel: Accelcovariance: Vec<f64>Trait Implementations
Sourceimpl Clone for AccelWithCovariance
impl Clone for AccelWithCovariance
Sourcefn clone(&self) -> AccelWithCovariance
fn clone(&self) -> AccelWithCovariance
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AccelWithCovariance
impl Debug for AccelWithCovariance
Sourceimpl Default for AccelWithCovariance
impl Default for AccelWithCovariance
Sourceimpl<'de> Deserialize<'de> for AccelWithCovariance
impl<'de> Deserialize<'de> for AccelWithCovariance
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AccelWithCovariance
impl PartialEq for AccelWithCovariance
Sourceimpl RosMessageType for AccelWithCovariance
impl RosMessageType for AccelWithCovariance
Sourceconst ROS_TYPE_NAME: &'static str = "geometry_msgs/AccelWithCovariance"
const ROS_TYPE_NAME: &'static str = "geometry_msgs/AccelWithCovariance"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "ad5a718d699c6be72a02b8d6a139f334"
const MD5SUM: &'static str = "ad5a718d699c6be72a02b8d6a139f334"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# This expresses acceleration in free space with uncertainty.\n\nAccel accel\n\n# Row-major representation of the 6x6 covariance matrix\n# The orientation parameters use a fixed-axis representation.\n# In order, the parameters are:\n# (x, y, z, rotation about X axis, rotation about Y axis, rotation about Z axis)\nfloat64[36] covariance"
const DEFINITION: &'static str = "# This expresses acceleration in free space with uncertainty.\n\nAccel accel\n\n# Row-major representation of the 6x6 covariance matrix\n# The orientation parameters use a fixed-axis representation.\n# In order, the parameters are:\n# (x, y, z, rotation about X axis, rotation about Y axis, rotation about Z axis)\nfloat64[36] covariance"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for AccelWithCovariance
impl Serialize for AccelWithCovariance
impl StructuralPartialEq for AccelWithCovariance