pub struct PolygonStamped {
pub header: Header,
pub polygon: Polygon,
}Fields
header: Headerpolygon: PolygonTrait Implementations
Sourceimpl Clone for PolygonStamped
impl Clone for PolygonStamped
Sourcefn clone(&self) -> PolygonStamped
fn clone(&self) -> PolygonStamped
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolygonStamped
impl Debug for PolygonStamped
Sourceimpl Default for PolygonStamped
impl Default for PolygonStamped
Sourceimpl<'de> Deserialize<'de> for PolygonStamped
impl<'de> Deserialize<'de> for PolygonStamped
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PolygonStamped
impl PartialEq for PolygonStamped
Sourceimpl RosMessageType for PolygonStamped
impl RosMessageType for PolygonStamped
Sourceconst ROS_TYPE_NAME: &'static str = "geometry_msgs/PolygonStamped"
const ROS_TYPE_NAME: &'static str = "geometry_msgs/PolygonStamped"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "56a3a2a80165092f696df3db62e18fbf"
const MD5SUM: &'static str = "56a3a2a80165092f696df3db62e18fbf"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# This represents a Polygon with reference coordinate frame and timestamp\n\nstd_msgs/Header header\nPolygon polygon"
const DEFINITION: &'static str = "# This represents a Polygon with reference coordinate frame and timestamp\n\nstd_msgs/Header header\nPolygon polygon"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for PolygonStamped
impl Serialize for PolygonStamped
impl StructuralPartialEq for PolygonStamped