pub struct WrenchStamped {
pub header: Header,
pub wrench: Wrench,
}Fields
header: Headerwrench: WrenchTrait Implementations
Sourceimpl Clone for WrenchStamped
impl Clone for WrenchStamped
Sourcefn clone(&self) -> WrenchStamped
fn clone(&self) -> WrenchStamped
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WrenchStamped
impl Debug for WrenchStamped
Sourceimpl Default for WrenchStamped
impl Default for WrenchStamped
Sourceimpl<'de> Deserialize<'de> for WrenchStamped
impl<'de> Deserialize<'de> for WrenchStamped
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for WrenchStamped
impl PartialEq for WrenchStamped
Sourceimpl RosMessageType for WrenchStamped
impl RosMessageType for WrenchStamped
Sourceconst ROS_TYPE_NAME: &'static str = "geometry_msgs/WrenchStamped"
const ROS_TYPE_NAME: &'static str = "geometry_msgs/WrenchStamped"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "5bc71556ab354cd6274d262a7de094a5"
const MD5SUM: &'static str = "5bc71556ab354cd6274d262a7de094a5"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# A wrench with reference coordinate frame and timestamp\n\nstd_msgs/Header header\nWrench wrench"
const DEFINITION: &'static str = "# A wrench with reference coordinate frame and timestamp\n\nstd_msgs/Header header\nWrench wrench"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for WrenchStamped
impl Serialize for WrenchStamped
impl StructuralPartialEq for WrenchStamped