pub struct Joy {
pub header: Header,
pub axes: Vec<f32>,
pub buttons: Vec<i32>,
}Fields
header: Headeraxes: Vec<f32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Joy
impl<'de> Deserialize<'de> for Joy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl RosMessageType for Joy
impl RosMessageType for Joy
Sourceconst ROS_TYPE_NAME: &'static str = "sensor_msgs/Joy"
const ROS_TYPE_NAME: &'static str = "sensor_msgs/Joy"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "967f985c9ca9013a4669430613e3e016"
const MD5SUM: &'static str = "967f985c9ca9013a4669430613e3e016"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Reports the state of a joystick\'s axes and buttons.\n\n# The timestamp is the time at which data is received from the joystick.\nstd_msgs/Header header\n\n# The axes measurements from a joystick.\nfloat32[] axes\n\n# The buttons measurements from a joystick.\nint32[] buttons"
const DEFINITION: &'static str = "# Reports the state of a joystick\'s axes and buttons.\n\n# The timestamp is the time at which data is received from the joystick.\nstd_msgs/Header header\n\n# The axes measurements from a joystick.\nfloat32[] axes\n\n# The buttons measurements from a joystick.\nint32[] buttons"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
impl StructuralPartialEq for Joy