pub struct MagneticField {
pub header: Header,
pub magnetic_field: Vector3,
pub magnetic_field_covariance: Vec<f64>,
}Fields
header: Headermagnetic_field: Vector3magnetic_field_covariance: Vec<f64>Trait Implementations
Sourceimpl Clone for MagneticField
impl Clone for MagneticField
Sourcefn clone(&self) -> MagneticField
fn clone(&self) -> MagneticField
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MagneticField
impl Debug for MagneticField
Sourceimpl Default for MagneticField
impl Default for MagneticField
Sourceimpl<'de> Deserialize<'de> for MagneticField
impl<'de> Deserialize<'de> for MagneticField
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for MagneticField
impl PartialEq for MagneticField
Sourceimpl RosMessageType for MagneticField
impl RosMessageType for MagneticField
Sourceconst ROS_TYPE_NAME: &'static str = "sensor_msgs/MagneticField"
const ROS_TYPE_NAME: &'static str = "sensor_msgs/MagneticField"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "c8761d20eb9dc59addd882f1d4de2266"
const MD5SUM: &'static str = "c8761d20eb9dc59addd882f1d4de2266"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Measurement of the Magnetic Field vector at a specific location.\n#\n# If the covariance of the measurement is known, it should be filled in.\n# If all you know is the variance of each measurement, e.g. from the datasheet,\n# just put those along the diagonal.\n# A covariance matrix of all zeros will be interpreted as \"covariance unknown\",\n# and to use the data a covariance will have to be assumed or gotten from some\n# other source.\n\nstd_msgs/Header header # timestamp is the time the\n # field was measured\n # frame_id is the location and orientation\n # of the field measurement\n\ngeometry_msgs/Vector3 magnetic_field # x, y, and z components of the\n # field vector in Tesla\n # If your sensor does not output 3 axes,\n # put NaNs in the components not reported.\n\nfloat64[9] magnetic_field_covariance # Row major about x, y, z axes\n # 0 is interpreted as variance unknown"
const DEFINITION: &'static str = "# Measurement of the Magnetic Field vector at a specific location.\n#\n# If the covariance of the measurement is known, it should be filled in.\n# If all you know is the variance of each measurement, e.g. from the datasheet,\n# just put those along the diagonal.\n# A covariance matrix of all zeros will be interpreted as \"covariance unknown\",\n# and to use the data a covariance will have to be assumed or gotten from some\n# other source.\n\nstd_msgs/Header header # timestamp is the time the\n # field was measured\n # frame_id is the location and orientation\n # of the field measurement\n\ngeometry_msgs/Vector3 magnetic_field # x, y, and z components of the\n # field vector in Tesla\n # If your sensor does not output 3 axes,\n # put NaNs in the components not reported.\n\nfloat64[9] magnetic_field_covariance # Row major about x, y, z axes\n # 0 is interpreted as variance unknown"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for MagneticField
impl Serialize for MagneticField
impl StructuralPartialEq for MagneticField