pub struct TimeReference {
pub header: Header,
pub time_ref: Time,
pub source: String,
}Fields
header: Headertime_ref: Timesource: StringTrait Implementations
Sourceimpl Clone for TimeReference
impl Clone for TimeReference
Sourcefn clone(&self) -> TimeReference
fn clone(&self) -> TimeReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TimeReference
impl Debug for TimeReference
Sourceimpl Default for TimeReference
impl Default for TimeReference
Sourceimpl<'de> Deserialize<'de> for TimeReference
impl<'de> Deserialize<'de> for TimeReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TimeReference
impl PartialEq for TimeReference
Sourceimpl RosMessageType for TimeReference
impl RosMessageType for TimeReference
Sourceconst ROS_TYPE_NAME: &'static str = "sensor_msgs/TimeReference"
const ROS_TYPE_NAME: &'static str = "sensor_msgs/TimeReference"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "7cb7ae5aa838323e9028637e304e0ad7"
const MD5SUM: &'static str = "7cb7ae5aa838323e9028637e304e0ad7"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Measurement from an external time source not actively synchronized with the system clock.\n\nstd_msgs/Header header # stamp is system time for which measurement was valid\n # frame_id is not used\n\nbuiltin_interfaces/Time time_ref # corresponding time from this external source\nstring source # (optional) name of time source"
const DEFINITION: &'static str = "# Measurement from an external time source not actively synchronized with the system clock.\n\nstd_msgs/Header header # stamp is system time for which measurement was valid\n # frame_id is not used\n\nbuiltin_interfaces/Time time_ref # corresponding time from this external source\nstring source # (optional) name of time source"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for TimeReference
impl Serialize for TimeReference
impl StructuralPartialEq for TimeReference