pub struct UInt8MultiArray {
pub layout: MultiArrayLayout,
pub data: Vec<u8>,
}Fields
layout: MultiArrayLayoutdata: Vec<u8>Trait Implementations
Sourceimpl Clone for UInt8MultiArray
impl Clone for UInt8MultiArray
Sourcefn clone(&self) -> UInt8MultiArray
fn clone(&self) -> UInt8MultiArray
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UInt8MultiArray
impl Debug for UInt8MultiArray
Sourceimpl Default for UInt8MultiArray
impl Default for UInt8MultiArray
Sourceimpl<'de> Deserialize<'de> for UInt8MultiArray
impl<'de> Deserialize<'de> for UInt8MultiArray
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UInt8MultiArray
impl PartialEq for UInt8MultiArray
Sourceimpl RosMessageType for UInt8MultiArray
impl RosMessageType for UInt8MultiArray
Sourceconst ROS_TYPE_NAME: &'static str = "std_msgs/UInt8MultiArray"
const ROS_TYPE_NAME: &'static str = "std_msgs/UInt8MultiArray"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "82373f1612381bb6ee473b5cd6f5d89c"
const MD5SUM: &'static str = "82373f1612381bb6ee473b5cd6f5d89c"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# This was originally provided as an example message.\n# It is deprecated as of Foxy\n# It is recommended to create your own semantically meaningful message.\n# However if you would like to continue using this please use the equivalent in example_msgs.\n\n# Please look at the MultiArrayLayout message definition for\n# documentation on all multiarrays.\n\nMultiArrayLayout layout # specification of data layout\nuint8[] data # array of data"
const DEFINITION: &'static str = "# This was originally provided as an example message.\n# It is deprecated as of Foxy\n# It is recommended to create your own semantically meaningful message.\n# However if you would like to continue using this please use the equivalent in example_msgs.\n\n# Please look at the MultiArrayLayout message definition for\n# documentation on all multiarrays.\n\nMultiArrayLayout layout # specification of data layout\nuint8[] data # array of data"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for UInt8MultiArray
impl Serialize for UInt8MultiArray
impl StructuralPartialEq for UInt8MultiArray