pub struct EmptyResponse {}Trait Implementations
Sourceimpl Clone for EmptyResponse
impl Clone for EmptyResponse
Sourcefn clone(&self) -> EmptyResponse
fn clone(&self) -> EmptyResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmptyResponse
impl Debug for EmptyResponse
Sourceimpl<'de> Deserialize<'de> for EmptyResponse
impl<'de> Deserialize<'de> for EmptyResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for EmptyResponse
impl PartialEq for EmptyResponse
Sourceimpl RosMessageType for EmptyResponse
impl RosMessageType for EmptyResponse
Sourceconst ROS_TYPE_NAME: &'static str = "std_srvs/EmptyResponse"
const ROS_TYPE_NAME: &'static str = "std_srvs/EmptyResponse"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "d41d8cd98f00b204e9800998ecf8427e"
const MD5SUM: &'static str = "d41d8cd98f00b204e9800998ecf8427e"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = ""
const DEFINITION: &'static str = ""
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for EmptyResponse
impl Serialize for EmptyResponse
impl StructuralPartialEq for EmptyResponse