pub struct SetBoolResponse {
pub success: bool,
pub message: String,
}Fields
success: boolmessage: StringTrait Implementations
Sourceimpl Clone for SetBoolResponse
impl Clone for SetBoolResponse
Sourcefn clone(&self) -> SetBoolResponse
fn clone(&self) -> SetBoolResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetBoolResponse
impl Debug for SetBoolResponse
Sourceimpl Default for SetBoolResponse
impl Default for SetBoolResponse
Sourceimpl<'de> Deserialize<'de> for SetBoolResponse
impl<'de> Deserialize<'de> for SetBoolResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SetBoolResponse
impl PartialEq for SetBoolResponse
Sourceimpl RosMessageType for SetBoolResponse
impl RosMessageType for SetBoolResponse
Sourceconst ROS_TYPE_NAME: &'static str = "std_srvs/SetBoolResponse"
const ROS_TYPE_NAME: &'static str = "std_srvs/SetBoolResponse"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "937c9679a518e3a18d831e57125ea522"
const MD5SUM: &'static str = "937c9679a518e3a18d831e57125ea522"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "bool success # indicate successful run of triggered service\nstring message # informational, e.g. for error messages"
const DEFINITION: &'static str = "bool success # indicate successful run of triggered service\nstring message # informational, e.g. for error messages"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for SetBoolResponse
impl Serialize for SetBoolResponse
impl StructuralPartialEq for SetBoolResponse