pub struct VisionInfo {
pub header: Header,
pub method: String,
pub database_location: String,
pub database_version: i32,
}Fields
header: Headermethod: Stringdatabase_location: Stringdatabase_version: i32Trait Implementations
Sourceimpl Clone for VisionInfo
impl Clone for VisionInfo
Sourcefn clone(&self) -> VisionInfo
fn clone(&self) -> VisionInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VisionInfo
impl Debug for VisionInfo
Sourceimpl Default for VisionInfo
impl Default for VisionInfo
Sourceimpl<'de> Deserialize<'de> for VisionInfo
impl<'de> Deserialize<'de> for VisionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for VisionInfo
impl PartialEq for VisionInfo
Sourceimpl RosMessageType for VisionInfo
impl RosMessageType for VisionInfo
Sourceconst ROS_TYPE_NAME: &'static str = "vision_msgs/VisionInfo"
const ROS_TYPE_NAME: &'static str = "vision_msgs/VisionInfo"
Expected to be the combination pkg_name/type_name string describing the type to ros
Example: std_msgs/Header
Sourceconst MD5SUM: &'static str = "1261a1749ba015f9bcafb51e88a7d01e"
const MD5SUM: &'static str = "1261a1749ba015f9bcafb51e88a7d01e"
The computed md5sum of the message file and its dependencies
This field is optional, and only needed when using ros1 native communication
Sourceconst DEFINITION: &'static str = "# Provides meta-information about a visual pipeline.\n#\n# This message serves a similar purpose to sensor_msgs/CameraInfo, but instead\n# of being tied to hardware, it represents information about a specific\n# computer vision pipeline. This information stays constant (or relatively\n# constant) over time, and so it is wasteful to send it with each individual\n# result. By listening to these messages, subscribers will receive\n# the context in which published vision messages are to be interpreted.\n# Each vision pipeline should publish its VisionInfo messages to its own topic,\n# in a manner similar to CameraInfo.\n\n# Used for sequencing\nstd_msgs/Header header\n\n# Name of the vision pipeline. This should be a value that is meaningful to an\n# outside user.\nstring method\n\n# Location where the metadata database is stored. The recommended location is\n# as an XML string on the ROS parameter server, but the exact implementation\n# and information is left up to the user.\n# The database should store information attached to class ids. Each\n# class id should map to an atomic, visually recognizable element. This\n# definition is intentionally vague to allow extreme flexibility. The\n# elements could be classes in a pixel segmentation algorithm, object classes\n# in a detector, different people\'s faces in a face detection algorithm, etc.\n# Vision pipelines report results in terms of numeric IDs, which map into\n# this database.\n# The information stored in this database is, again, left up to the user. The\n# database could be as simple as a map from ID to class name, or it could\n# include information such as object meshes or colors to use for\n# visualization.\nstring database_location\n\n# Metadata database version. This counter is incremented\n# each time the pipeline begins using a new version of the database (useful\n# in the case of online training or user modifications).\n# The counter value can be monitored by listeners to ensure that the pipeline\n# and the listener are using the same metadata.\nint32 database_version"
const DEFINITION: &'static str = "# Provides meta-information about a visual pipeline.\n#\n# This message serves a similar purpose to sensor_msgs/CameraInfo, but instead\n# of being tied to hardware, it represents information about a specific\n# computer vision pipeline. This information stays constant (or relatively\n# constant) over time, and so it is wasteful to send it with each individual\n# result. By listening to these messages, subscribers will receive\n# the context in which published vision messages are to be interpreted.\n# Each vision pipeline should publish its VisionInfo messages to its own topic,\n# in a manner similar to CameraInfo.\n\n# Used for sequencing\nstd_msgs/Header header\n\n# Name of the vision pipeline. This should be a value that is meaningful to an\n# outside user.\nstring method\n\n# Location where the metadata database is stored. The recommended location is\n# as an XML string on the ROS parameter server, but the exact implementation\n# and information is left up to the user.\n# The database should store information attached to class ids. Each\n# class id should map to an atomic, visually recognizable element. This\n# definition is intentionally vague to allow extreme flexibility. The\n# elements could be classes in a pixel segmentation algorithm, object classes\n# in a detector, different people\'s faces in a face detection algorithm, etc.\n# Vision pipelines report results in terms of numeric IDs, which map into\n# this database.\n# The information stored in this database is, again, left up to the user. The\n# database could be as simple as a map from ID to class name, or it could\n# include information such as object meshes or colors to use for\n# visualization.\nstring database_location\n\n# Metadata database version. This counter is incremented\n# each time the pipeline begins using a new version of the database (useful\n# in the case of online training or user modifications).\n# The counter value can be monitored by listeners to ensure that the pipeline\n# and the listener are using the same metadata.\nint32 database_version"
The definition from the msg, srv, or action file
This field is optional, and only needed when using ros1 native communication
Sourceimpl Serialize for VisionInfo
impl Serialize for VisionInfo
impl StructuralPartialEq for VisionInfo